View source: R/as_contact_survey.R
| as_contact_survey | R Documentation |
Checks that a survey fulfills all the requirements to work with the 'contact_matrix' function
as_contact_survey(
x,
id_column = "part_id",
country_column = NULL,
year_column = NULL,
...,
id.column = deprecated(),
country.column = deprecated(),
year.column = deprecated()
)
x |
list containing
|
id_column |
the column in both the |
country_column |
the column in the |
year_column |
the column in the |
... |
additional arguments (currently ignored) |
id.column, country.column, year.column |
invisibly returns a character vector of the relevant columns
data(polymod)
check(polymod)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.