assemble_survey: Assemble a contact survey with new participant/contact data

View source: R/subset-contact-survey.R

assemble_surveyR Documentation

Assemble a contact survey with new participant/contact data

Description

Creates a new survey object preserving all fields from the original, replacing only participants and contacts with the supplied data.

Usage

assemble_survey(x, participants, contacts)

Arguments

x

a contact_survey object

participants

new participants data.table

contacts

new contacts data.table

Value

a contact_survey object with all fields from x preserved


socialmixr documentation built on April 29, 2026, 9:07 a.m.