| download_survey | R Documentation |
download_survey() has been deprecated in favour of
contactsurveys::download_survey().
download_survey() downloads survey data from Zenodo.
download_survey(survey, dir = NULL, sleep = 1)
survey |
a URL (see |
dir |
a directory to save the files to; if not given, will save to a temporary directory |
sleep |
time to sleep between requests to avoid overloading the server
(passed on to |
a vector of filenames that can be used with load_survey
load_survey
# we recommend using the contactsurveys package for download_survey()
## Not run:
# if needed, discover surveys with:
contactsurveys::list_surveys()
peru_survey <- download_survey("https://doi.org/10.5281/zenodo.1095664")
# -->
peru_survey <- contactsurveys::download_survey(
"https://doi.org/10.5281/zenodo.1095664"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.