find_unique_key: Find the minimal unique key for a data.table

View source: R/load-survey-utils.R

find_unique_keyR Documentation

Find the minimal unique key for a data.table

Description

Given a data.table and a base identifier column, finds the minimal set of additional columns needed to uniquely identify each row.

Usage

find_unique_key(data, base_id = "part_id")

Arguments

data

A data.table

base_id

The base identifier column name (default: "part_id")

Value

A character vector of column names that form the unique key


socialmixr documentation built on April 29, 2026, 9:07 a.m.