View source: R/contact-matrix-utils.R
| impute_ages | R Documentation |
Generic function to impute ages from min/max ranges. Works for both participant and contact data by specifying the column prefix.
impute_ages(data, prefix, estimate = c("mean", "sample", "missing"))
data |
A data.table containing age data |
prefix |
Column name prefix: "part_age" for participants, "cnt_age" for contacts |
estimate |
Imputation method: "mean", "sample", or "missing" |
The data with ages imputed according to the specified method
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.