list_surveys: List all surveys available for download

View source: R/deprecated.R

list_surveysR Documentation

List all surveys available for download

Description

[Deprecated]

list_surveys() has been deprecated in favour of contactsurveys::list_surveys().

Usage

list_surveys(clear_cache = FALSE)

Arguments

clear_cache

logical, whether to clear the cache before downloading the survey; by default, the cache is not cleared and so multiple calls of this function to access the same survey will not result in repeated downloads.

Value

character vector of surveys

Examples

# we recommend using the contactsurveys package now for listing surveys.
## Not run: 
contactsurveys::list_surveys()

## End(Not run)

socialmixr documentation built on April 29, 2026, 9:07 a.m.