| pop_age | R Documentation |
This changes population data to have age groups with the given age_limits, extrapolating linearly between age groups (if more are requested than available) and summing populations (if fewer are requested than available)
pop_age(
pop,
age_limits = NULL,
pop_age_column = "lower.age.limit",
pop_column = "population",
...,
age.limits = deprecated(),
pop.age.column = deprecated(),
pop.column = deprecated()
)
pop |
a data frame with columns indicating lower age limits and population sizes (see 'pop_age_column' and 'pop_column') |
age_limits |
lower age limits of age groups to extract; if NULL (default), the population data is returned unchanged |
pop_age_column |
column in the 'pop' data frame indicating the lower age group limit |
pop_column |
column in the 'pop' data frame indicating the population size |
... |
ignored |
age.limits, pop.age.column, pop.column |
data frame of age-specific population data
ages_it_2015 <- wpp_age("Italy", 2015)
# Modify the age data.frame to get age groups of 10 years instead of 5
pop_age(ages_it_2015, age_limits = seq(0, 100, by = 10))
# The function will also automatically interpolate if necessary
pop_age(ages_it_2015, age_limits = c(0, 18, 40, 65))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.