reduce_agegroups: Reduce the number of age groups given a broader set of limits

View source: R/reduce_agegroups.R

reduce_agegroupsR Documentation

Reduce the number of age groups given a broader set of limits

Description

Operates on lower limits

Usage

reduce_agegroups(x, limits)

Arguments

x

vector of limits

limits

new limits

Value

vector with the new age groups

Examples

reduce_agegroups(seq_len(20), c(0, 5, 10))

socialmixr documentation built on April 29, 2026, 9:07 a.m.