View source: R/subset-contact-survey.R
| assemble_survey | R Documentation |
Creates a new survey object preserving all fields from the original,
replacing only participants and contacts with the supplied data.
assemble_survey(x, participants, contacts)
x |
a |
participants |
new participants data.table |
contacts |
new contacts data.table |
a contact_survey object with all fields from x preserved
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.