assemble_survey: Assemble a contact survey with new participant/contact data
Description
Creates a new survey object preserving all fields from the original,
replacing only participants and contacts with the supplied data.
Usage
assemble_survey(x, participants, contacts)
Value
a contact_survey object with all fields from x preserved
Arguments
- x
a contact_survey object
- participants
new participants data.table
- contacts
new contacts data.table