Samples a contact survey
contact_matrix(
survey,
countries = NULL,
survey_pop = NULL,
age_limits = NULL,
filter = NULL,
counts = FALSE,
symmetric = FALSE,
split = FALSE,
sample_participants = FALSE,
estimated_participant_age = c("mean", "sample", "missing"),
estimated_contact_age = c("mean", "sample", "missing"),
missing_participant_age = c("remove", "keep"),
missing_contact_age = c("remove", "sample", "keep", "ignore"),
weights = NULL,
weigh_dayofweek = FALSE,
weigh_age = FALSE,
weight_threshold = NA,
symmetric_norm_threshold = 2,
sample_all_age_groups = FALSE,
sample_participants_max_tries = 1000,
return_part_weights = FALSE,
return_demography = NA,
per_capita = FALSE,
...,
survey.pop = deprecated(),
age.limits = deprecated(),
sample.participants = deprecated(),
estimated.participant.age = deprecated(),
estimated.contact.age = deprecated(),
missing.participant.age = deprecated(),
missing.contact.age = deprecated(),
weigh.dayofweek = deprecated(),
weigh.age = deprecated(),
weight.threshold = deprecated(),
symmetric.norm.threshold = deprecated(),
sample.all.age.groups = deprecated(),
sample.participants.max.tries = deprecated(),
return.part.weights = deprecated(),
return.demography = deprecated(),
per.capita = deprecated()
)a contact matrix, and the underlying demography of the surveyed population
a survey() object.
limit to one or more countries; if NULL (default), will use all countries in the survey; these can be given as country names or 2-letter (ISO Alpha-2) country codes.
survey population -- a data frame with columns
lower.age.limit and population. Passing NULL (the default)
or a character vector of country names triggers the
implicit lookup via
wpp_age()
when symmetric, split, per_capita, weigh_age, or
return_demography is TRUE; supply an explicit data frame
(e.g. constructed from the wpp2024 package or another source)
instead. If the population is coarser than the requested age groups it
is linearly interpolated to finer groups, but this is deprecated (it
warns and will error in a future release); supply population at least as
fine as age_limits.
lower limits of the age groups over which to construct the matrix. If NULL (default), age limits are inferred from participant and contact ages.
any filters to apply to the data, given as list of the form (column=filter_value) - only contacts that have 'filter_value' in 'column' will be considered. If multiple filters are given, they are all applied independently and in the sequence given. Default value is NULL; no filtering performed.
whether to return counts (instead of means).
whether to make matrix symmetric, such that \(c_{ij}N_i = c_{ji}N_j\).
whether to split the contact matrix into the mean
number of contacts, in each age group (split further into the
product of the mean number of contacts across the whole
population (mean.contacts), a normalisation constant
(normalisation) and age-specific variation in contacts
(contacts)), multiplied with an assortativity matrix
(assortativity) and a population multiplier (demography).
For more detail on this, see the "Getting Started" vignette.
whether to sample participants randomly (with replacement); done multiple times this can be used to assess uncertainty in the generated contact matrices. See the "Bootstrapping" section in the vignette for how to do this.
if set to "mean" (default), people whose ages are given as a range (in columns named "..._est_min" and "..._est_max") but not exactly (in a column named "..._exact") will have their age set to the mid-point of the range; if set to "sample", the age will be sampled from the range; if set to "missing", age ranges will be treated as missing
if set to "mean" (default), contacts whose ages are given as a range (in columns named "..._est_min" and "..._est_max") but not exactly (in a column named "..._exact") will have their age set to the mid-point of the range; if set to "sample", the age will be sampled from the range; if set to "missing", age ranges will be treated as missing.
if set to "remove" (default), participants without age information are removed; if set to "keep", participants with missing age are kept and will appear in the contact matrix in a row labelled "NA".
if set to "remove" (default), participants that have contacts without age information are removed; if set to "keep", contacts with missing age are kept and will appear in the contact matrix in a column labelled "NA"; if set to "ignore", contacts without age information are removed from the analysis (but the participants that made them are kept). The "sample" option is defunct (errors).
column name(s) of the participant data of the
survey() object with user-specified weights (default =
empty vector).
whether to weigh social contacts data by the day of the week (weight (5/7 / N_week / N) for weekdays and (2/7 / N_weekend / N) for weekends).
whether to weigh social contacts data by the age of the participants (vs. the populations' age distribution).
threshold value for the standardized weights before running an additional standardisation (default 'NA' = no cutoff).
threshold value for the
normalization weights when symmetric = TRUE before showing
a warning that that large differences in the size of the
sub-populations are likely to result in artefacts when making
the matrix symmetric (default 2).
what to do if sampling
participants (with sample_participants = TRUE) fails to
sample participants from one or more age groups; if FALSE
(default), corresponding rows will be set to NA, if TRUE the
sample will be discarded and a new one taken instead.
maximum number of attempts
when sample_all_age_groups = TRUE; defaults to 1000.
boolean to return the participant weights.
boolean to explicitly return demography data that corresponds to the survey data (default 'NA' = if demography data is requested by other function parameters).
whether to return a matrix with contact rates per capita (default is FALSE and not possible if 'counts=TRUE' or 'split=TRUE').
further arguments to pass to get_survey()
and check() (especially column names).
Use the underscore-separated versions of these arguments instead.
Sebastian Funk
data(polymod)
contact_matrix(
survey = polymod,
countries = "United Kingdom",
age_limits = c(0, 1, 5, 15)
)
Run the code above in your browser using DataLab