Learn R Programming

socialmixr (version 0.7.0)

download_survey: Download a survey from its Zenodo repository

Description

[Defunct]

download_survey() is defunct. Use contactsurveys::download_survey() instead.

download_survey() downloads survey data from Zenodo.

Usage

download_survey(survey, dir = NULL, sleep = 1)

Value

Always errors.

Arguments

survey

a URL (see contactsurveys::list_surveys())

dir

a directory to save the files to; if not given, will save to a temporary directory

sleep

time to sleep between requests to avoid overloading the server (passed on to Sys.sleep)

See Also

load_survey

Examples

Run this code
# we recommend using the contactsurveys package for download_survey()
if (FALSE) {
# if needed, discover surveys with:
contactsurveys::list_surveys()
peru_survey <- download_survey("https://doi.org/10.5281/zenodo.1095664")
# -->
peru_survey <- contactsurveys::download_survey(
  "https://doi.org/10.5281/zenodo.1095664"
)
}

Run the code above in your browser using DataLab