View source: R/load-survey-utils.R
| find_unique_key | R Documentation |
Given a data.table and a base identifier column, finds the minimal set of additional columns needed to uniquely identify each row.
find_unique_key(data, base_id = "part_id")
data |
A data.table |
base_id |
The base identifier column name (default: "part_id") |
A character vector of column names that form the unique key
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.