| list_surveys | R Documentation |
list_surveys() has been deprecated in favour of
contactsurveys::list_surveys().
list_surveys(clear_cache = FALSE)
clear_cache |
logical, whether to clear the cache before downloading the survey; by default, the cache is not cleared and so multiple calls of this function to access the same survey will not result in repeated downloads. |
character vector of surveys
# we recommend using the contactsurveys package now for listing surveys.
## Not run:
contactsurveys::list_surveys()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.