Learn R Programming

socialmixr (version 0.7.0)

list_surveys: List all surveys available for download

Description

[Defunct]

list_surveys() is defunct. Use contactsurveys::list_surveys() instead.

Usage

list_surveys(clear_cache = FALSE)

Value

Always errors.

Arguments

clear_cache

logical, whether to clear the cache before downloading the survey; by default, the cache is not cleared and so multiple calls of this function to access the same survey will not result in repeated downloads.

Examples

Run this code
# we recommend using the contactsurveys package now for listing surveys.
if (FALSE) {
contactsurveys::list_surveys()
}

Run the code above in your browser using DataLab