list_surveys: List all surveys available for download
Description
list_surveys() is defunct. Use contactsurveys::list_surveys() instead.
Usage
list_surveys(clear_cache = FALSE)
Value
Always errors.
Arguments
clear_cache
logical, whether to clear the cache before downloading
the survey; by default, the cache is not cleared and so multiple calls of
this function to access the same survey will not result in repeated
downloads.