This function combines the R image.plot function with numeric contact rates in the matrix cells.
matrix_plot(
mij,
min.legend = 0,
max.legend = NA,
num.digits = 2,
num.colors = 50,
main,
xlab,
ylab,
legend.width,
legend.mar,
legend.shrink,
cex.lab,
cex.axis,
cex.text,
color.palette = heat.colors
)a contact matrix containing contact rates between
participants of age i (rows) with contacts of age j
(columns). This is the default matrix format of
contact_matrix().
the color scale minimum (default = 0). Set
to NA to use the minimum value of mij.
the color scale maximum (default = NA). Set
to NA to use the maximum value of mij.
the number of digits when rounding the contact rates (default = 2). Use NA to disable this.
the number of color breaks (default = 50)
the figure title
a title for the x axis (default: "Age group (year)")
a title for the y axis (default: "Contact age group (year)")
width of the legend strip in characters. Default is 1.
width in characters of legend margin. Default is 5.1.
amount to shrink the size of legend relative to the full height or width of the plot. Default is 0.9.
size of the x and y labels (default: 1.2)
size of the axis labels (default: 0.8)
size of the numeric values in the matrix (default: 1)
the color palette to use (default:
heat.colors()). Other examples are topo.colors(),
terrain.colors() and hcl.colors(). User-defined
functions are also possible if they take the number of
colors to be in the palette as function argument.
Lander Willem
This is a function using basic R graphics to visualise a social contact matrix.
if (FALSE) {
data(polymod)
mij <- contact_matrix(
polymod,
countries = "United Kingdom",
age_limits = c(0, 18, 65)
)$matrix
matrix_plot(mij)
}
Run the code above in your browser using DataLab