View source: R/survey-country-population.R
| survey_country_population | R Documentation |
Looks up the country and year inside a survey, or a provided
"countries" value, and determines the corresponding demographics in the world
population prospects data using wpp_age().
survey_country_population(survey, countries = NULL)
survey |
A |
countries |
Optional. A character vector of country names. If specified, this will be used instead of the potential "country" column in "participants". |
A data table with population data by age group for the survey countries, aggregated by lower age limit. The function will error if no country information is available from either the survey or countries argument.
survey_country_population(polymod)
survey_country_population(polymod, countries = "Belgium")
survey_country_population(polymod, countries = c("Belgium", "Italy"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.