| wpp_countries | R Documentation |
This function is deprecated in favour of passing population data directly
to contact_matrix() via the survey_pop argument, which removes the need
for a country list. Additionally, the underlying wpp2017 data is outdated.
For countries available in more recent WPP editions, use the wpp2024
package from GitHub.
wpp_countries()
Uses the World Population Prospects data from the wpp2017 package.
list of countries
if (requireNamespace("wpp2017", quietly = TRUE)) {
wpp_countries()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.