Learn R Programming

socialmixr (version 0.7.0)

wpp_countries: List all countries and regions for which socialmixr has population data

Description

[Deprecated]

This function is deprecated in favour of passing population data directly to contact_matrix() via the survey_pop argument, which removes the need for a country list. Additionally, the underlying wpp2017 data is outdated. For countries available in more recent WPP editions, use the wpp2024 package from GitHub.

Usage

wpp_countries()

Arguments

Value

list of countries

Details

Uses the World Population Prospects data from the wpp2017 package.

Examples

Run this code
if (requireNamespace("wpp2017", quietly = TRUE)) {
  wpp_countries()
}

Run the code above in your browser using DataLab